require 'active_support/version'
require 'active_support/core_ext/module/aliasing'

module ActiveSupport
  class CustomLogger
    module InstanceMethods
      def formatted_timestamp
        "[#{Time.now.strftime('%FT%T')}]"
      end
    end
  end
  
  if ActiveSupport::VERSION::MAJOR == 3
    
    require 'active_support/buffered_logger'
    
    class BufferedLogger
      include CustomLogger::InstanceMethods
      
      def add_with_formatted_timestamp(severity, message = nil, progname = nil, &block)
        add_without_formatted_timestamp(severity, "#{formatted_timestamp} #{message}", progname, &block)
      end
      
      alias_method_chain :add, :formatted_timestamp
    end
    
  elsif ActiveSupport::VERSION::MAJOR >= 4
    
    require 'active_support/logger'
    
    class Logger < ::Logger
      class SimpleFormatter < ::Logger::Formatter
        include CustomLogger::InstanceMethods
        
        def call_with_formatted_timestamp(severity, timestamp, progname, msg)
          msg = "#{formatted_timestamp} #{msg}" if String === msg
          call_without_formatted_timestamp(severity, timestamp, progname, msg)
        end
        
        alias_method_chain :call, :formatted_timestamp
      end
    end
    
  else
    raise "Requires ActiveSupport >= 3"
  end
end

ActiveSupport::CustomLogger.const_set(:VERSION, "0.0.1")

require_relative 'custom_logger/railtie' if defined?(Rails::Railtie)